/***** PAFstr.h - Family data structures for PAF Version 2 data files *****/
/*$nestcmnt*/

struct namstr 
{                          /* 21-byte structure for name file */ 
    struct namstr *llink;  /* left link pointer */
    char nam[17];              /* name array */
    struct namstr *rlink;  /* right link pointer */
} namrec;
  
struct date4  
{                          /* 4-byte structure for dual-year date */
    char byte1date;        /* char defined to make */
    char byte2date;        /* manipulation easier with single bytes */
    char byte3date;        
    char byte4date;        
} dualdate;

struct date3  
{                          /* 3-byte structure for single-year date */
    char byt1date;       
    char byt2date;   
    char byt3date; 
} sdate;           


struct family 
{                              /*28-byte structure for marriage record data */
    struct indstr *hu;         /* husband pointer */
    struct indstr *wif;        /* wife pointer */
    struct indstr *ch;         /* child pointer */
    struct date4 mardate;      /* date structure for marriage date */
    struct namstr *mplace1;    /* pointers to marriage place */
    struct namstr *mplace2;
    struct namstr *mplace3;
    struct namstr *mplace4;
    struct date3 whsealdate;   /* seal date for wife/husband */
    struct namstr *temple;     /* pointer to wif/hus sealing temple */
    struct family *huom;       /* pointer to husband other marriage */
    struct family *wifom;      /* pointer to wife's other marriage */
    char divflg;               /* divorce flag */
} marrec;

struct indstr 
{                                  /*92 byte structure of indiv data */
    struct namstr *sname;          /* pointer to surname */
    struct namstr *gname1;         /* pointer to given name 1 */
    struct namstr *gname2;         /* pointer to given name 2 */
    struct namstr *gname3;         /* pointer to given name 3 */
    struct namstr *title;          /* pointer to individual title */
    char sex;                      /* sex of individual m/f */
    struct date4 bdate;            /* date structure for birthdate */
    struct namstr *bplace1;        /* pointers to birthplace */
    struct namstr *bplace2;
    struct namstr *bplace3;
    struct namstr *bplace4;
    struct date4 chdate;           /* date structure for christening date */
    struct namstr *cplace1;        /* pointers to christening place */
    struct namstr *cplace2;
    struct namstr *cplace3;
    struct namstr *cplace4;
    struct date4 ddate;            /* date structure for death date */
    struct namstr *dplace1;        /* pointers to death place */
    struct namstr *dplace2;
    struct namstr *dplace3;
    struct namstr *dplace4;
    struct date4 budate;           /* date structure for burial date */
    struct namstr *buplace1;       /* pointers to burial place */
    struct namstr *buplace2;
    struct namstr *buplace3;
    struct namstr *buplace4;
    struct date3 bapdate;          /* date structure for baptism date */
    struct namstr *baptemple;      /* pointer to baptism temple */
    struct date3 enddate;          /* date structure for endowment date */
    struct namstr *endtemple;      /* pointer to endowment temple */
    struct date3 cpsealdate;       /* date structure - seal child to parents */
    struct namstr *cpsealtemple;   /* child/parent sealing temple */
    struct indstr *oldsib;         /* older sibling pointer */
    struct family *ownmarr;        /* own marriage pointer */
    struct family *parmarr;        /* parents marriage pointer */
    char id[10];                   /* id field */
    unsigned *notes;               /* pointer to notes */
} indrec;

/*****<<<   end of PAFstr.h   >>>*****/
